==> firekeeper-0.2.3.tar.gz: firekeeper-0.2.3/components/parser/Error.h <==
/*$Id: Error.h,v 1.11 2006/09/03 19:00:50 jwrobel Exp $*/
/* ***** BEGIN LICENSE BLOCK *****
 *  This file is part of Firekeeper.
 *
 *  Copyright (C) 2006 Jan Wrobel <wrobel@blues.ath.cx>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * ***** END LICENSE BLOCK ***** */

#ifndef ERROR_H
#define ERROR_H 

#include "Common.h"

/*error reporting/debugging routines, similar to these introduced
  by Richard Stevens in his "Advanced Programming in the Unix Environment"*/

void err_ret(const char *fmt, ...);
void err_msg(const char *fmt, ...);
void err_sys(const char *fmt, ...);
void err_quit(const char *fmt, ...);
void stderr_print(const char *fmt, ...);
void trace_func(const char *funcname,  const char *fmt, ...);
void trace_func_windows(const char *fmt, ...);

#ifdef DEBUG

#define DEBUG_FUNCTIONS "::"
/*#define DEBUG_ALL 0 print debug informations only from DEBUG_FUNCTIONS*/

/*print debug information from all functions except
 *this specified in NOT_DEBUG_FUNCTIONS*/
#define DEBUG_ALL 1
#define NOT_DEBUG_FUNCTIONS ":parseOptions:"

#define FK_ASSERT(x) if (!(x)) err_quit("ASSERTion %s in file %s line %d filed", #x, __FILE__, __LINE__);


#ifndef MSVC

#define TRACE(x...) do{\
        char trace_buf[64]; \
        snprintf(trace_buf, 64, ":%s:", __func__); \
	if ((DEBUG_ALL && !strstr(NOT_DEBUG_FUNCTIONS, trace_buf)) ||\
	    strstr(DEBUG_FUNCTIONS, trace_buf))\
		       trace_func(__func__,  x);\
	    }while(0)



#else /*MSVC*/
/*How to append function name in Windows version of TRACE() macro?
  Now it writes only debug message without function that produced it*/
#define TRACE trace_func_windows


#endif /*MSVC*/

#else  /*DEBUG*/

#ifndef MSVC
#define TRACE(x...)  
#define FK_ASSERT(x)
#else /*MSVC*/
#define TRACE  
#define FK_ASSERT 
#endif /*MSVC*/


#endif /*DEBUG*/

#endif /*ERROR_H*/

==> firekeeper-0.2.9.tar.gz: firekeeper-0.2.9/components/parser/Error.h <==
/*$Id: Error.h,v 1.14 2006/11/04 21:09:26 jwrobel Exp $*/
/* ***** BEGIN LICENSE BLOCK *****
 *  This file is part of Firekeeper.
 *
 *  Copyright (C) 2006 Jan Wrobel <wrobel@blues.ath.cx>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * ***** END LICENSE BLOCK ***** */

#ifndef ERROR_H
#define ERROR_H 

#include "Common.h"

/*error reporting/debugging routines, similar to these introduced
  by Richard Stevens in his "Advanced Programming in the Unix Environment"*/

void err_ret(const char *fmt, ...);
void err_msg(const char *fmt, ...);
void err_sys(const char *fmt, ...);
void err_quit(const char *fmt, ...);


void stderr_print(const char *fmt, ...);
void trace_func(const char *funcname,  const char *fmt, ...);
void trace_func_windows(const char *fmt, ...);

#ifdef DEBUG


#define FK_ASSERT(x) if (!(x)) err_quit("ASSERTion %s in file %s line %d failed", #x, __FILE__, __LINE__);


#ifndef MSVC

//char trace_buf[64]; 
//snprintf(trace_buf, 64, ":%s:", __func__); 

#define TRACE(x...) do{\
        trace_func(__func__,  x);\
	}while(0)



#else /*MSVC*/
/*How to append function name in Windows version of TRACE() macro?
  Now it writes only debug message without function that produced it*/
#define TRACE trace_func_windows


#endif /*MSVC*/

#else  /*DEBUG*/

#ifndef MSVC
#define TRACE(x...)  
#define FK_ASSERT(x)
#else /*MSVC*/
#define TRACE  
#define FK_ASSERT 
#endif /*MSVC*/


#endif /*DEBUG*/

#endif /*ERROR_H*/
